componenttools.extend_in_parent_of_component
============================================

.. autofunction:: abjad.tools.componenttools.extend_in_parent_of_component.extend_in_parent_of_component
   :noindex:
